import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

// ---------------

describe('DELETE card', () => {
	let added_card;
	it('creating card without runner should return 200', async () => {
		const res = await axios.post(base + '/api/cards', null, axios_config);
		added_card = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('delete card', async () => {
		const res2 = await axios.delete(base + '/api/cards/' + added_card.id, axios_config);
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
		expect(res2.data).toEqual(added_card);
	});
	it('check if card really was deleted', async () => {
		const res3 = await axios.get(base + '/api/cards/' + added_card.id, axios_config);
		expect(res3.status).toEqual(404);
		expect(res3.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('DELETE card (non-existant)', () => {
	it('delete', async () => {
		const res2 = await axios.delete(base + '/api/cards/0', axios_config);
		expect(res2.status).toEqual(204);
	});
});
