import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});


describe('POST /api/scans illegally', () => {
	let added_org;
	let added_runner;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organisations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('no input should return 400', async () => {
		const res = await axios.post(base + '/api/scans', null, axios_config);
		expect(res.status).toEqual(400);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('no distance should return 400', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id
		}, axios_config);
		expect(res.status).toEqual(400);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('illegal distance input should return 400', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": -1
		}, axios_config);
		expect(res.status).toEqual(400);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('invalid runner input should return 404', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": 999999999999999999999999,
			"distance": 100
		}, axios_config);
		expect(res.status).toEqual(404);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('POST /api/scans successfully', () => {
	let added_org;
	let added_runner;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organisations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		delete res2.data.group;
		delete res2.data.distance;
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('creating a scan with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 200
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.runner.distance;
		expect(res.data).toEqual({
			"runner": added_runner,
			"distance": 200,
			"valid": true
		});
	});
	it('creating a valid scan should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 200,
			"valid": true
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.runner.distance;
		expect(res.data).toEqual({
			"runner": added_runner,
			"distance": 200,
			"valid": true
		});
	});
	it('creating a invalid scan should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 200,
			"valid": false
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.runner.distance;
		expect(res.data).toEqual({
			"runner": added_runner,
			"distance": 200,
			"valid": false
		});
	});
});
// ---------------
describe('POST /api/scans successfully via scan station', () => {
	let added_org;
	let added_runner;
	let added_track;
	let added_station;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organisations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		delete res2.data.group;
		delete res2.data.distance;
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('creating a track with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/tracks', {
			"name": "testtrack",
			"distance": 200,
		}, axios_config);
		added_track = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
	it('creating a station with minimum parameters should return 200', async () => {
		const res = await axios.post(base + '/api/stations', {
			"track": added_track.id
		}, axios_config);
		added_station = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
	it('creating a scan with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 200
		}, {
			headers: { "authorization": "Bearer " + added_station.key },
			validateStatus: undefined
		});
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.runner.distance;
		expect(res.data).toEqual({
			"runner": added_runner,
			"distance": 200,
			"valid": true
		});
	});
	it('creating a valid scan should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 200,
			"valid": true
		}, {
			headers: { "authorization": "Bearer " + added_station.key },
			validateStatus: undefined
		});
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.runner.distance;
		expect(res.data).toEqual({
			"runner": added_runner,
			"distance": 200,
			"valid": true
		});
	});
	it('creating a invalid scan should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 200,
			"valid": false
		}, {
			headers: { "authorization": "Bearer " + added_station.key },
			validateStatus: undefined
		});
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.runner.distance;
		expect(res.data).toEqual({
			"runner": added_runner,
			"distance": 200,
			"valid": false
		});
	});
});
