import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

// ---------------

describe('DELETE scan', () => {
	let added_org;
	let added_runner;
	let added_scan;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organisations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('correct distance and runner input should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 1000
		}, axios_config);
		added_scan = res.data;
		delete res.data.runner.distance;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('delete scan', async () => {
		const res2 = await axios.delete(base + '/api/scans/' + added_scan.id, axios_config);
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
		delete res2.data.runner.distance;
		expect(res2.data).toEqual(added_scan);
	});
	it('check if scan really was deleted', async () => {
		const res3 = await axios.get(base + '/api/scans/' + added_scan.id, axios_config);
		expect(res3.status).toEqual(404);
		expect(res3.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('DELETE scan (non-existant)', () => {
	it('delete', async () => {
		const res2 = await axios.delete(base + '/api/scans/0', axios_config);
		expect(res2.status).toEqual(204);
	});
});
