import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

// ---------------
describe('DELETE station', () => {
	let added_track;
	let added_station;
	it('creating a track with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/tracks', {
			"name": "testtrack",
			"distance": 200,
		}, axios_config);
		added_track = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
	it('creating a station with minimum parameters should return 200', async () => {
		const res = await axios.post(base + '/api/stations', {
			"track": added_track.id
		}, axios_config);
		added_station = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
	it('delete station', async () => {
		const res2 = await axios.delete(base + '/api/stations/' + added_station.id, axios_config);
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
		delete res2.data.key;
		delete added_station.key;
		expect(res2.data).toEqual(added_station);
	});
	it('check if station really was deleted', async () => {
		const res3 = await axios.get(base + '/api/stations/' + added_station.id, axios_config);
		expect(res3.status).toEqual(404);
		expect(res3.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('DELETE station (non-existant)', () => {
	it('delete', async () => {
		const res2 = await axios.delete(base + '/api/stations/0', axios_config);
		expect(res2.status).toEqual(204);
	});
});
